@@ -3,7 +3,7 @@ use warnings;
 
 package Oh;
 
-our $VERSION = 0.00001;
+our $VERSION = 0.01;
 
 use subs qw/error env listp evaluate_element evaluate_list evaluate_function evaluate_builtin evaluate_macro evaluate_lambda find search progn read_element read_string read_list reft/;
 
@@ -552,7 +552,8 @@ sub scheme_args
         if ($arg eq '.')
         {
           my $name = shift;
-          $env->{symbol}->{$name} = [@args];
+          $env->{symbol}->{$name} = \@args;
+          last;
         }
         else
         {
@@ -992,7 +993,15 @@ fun { progn(@_) } 'eval';
 #fun { \@_ } 'list';
 fun { pr(@_) } 'pr';
 fun { pr("@_\n") } 'print';
+fun { $_[0]->[0] } 'car';
+fun
+{
+  my @list = @{$_[0]};
+  shift @list;
+  \@list;
+} 'cdr';
 fun { +{ @_ } } 'hash';
+fun { listp ref $_[0] } 'listp';
 fun { my ($obj, $method, @args) = @_; $obj->$method(@args) } 'method';
 
 interpret_string <<'oh';
@@ -1001,6 +1010,10 @@ interpret_string <<'oh';
 (macro lambda (args . code) `(anon (lisp-args ,args) ,@code))
 (macro perl-fun (module name args . code) `(perl-sub ,module ,name (scheme-args ,args) ,@code))
 (macro perl-defun (module name args . code) `(perl-sub ,module ,name (lisp-args ,args) ,@code))
+(macro define (name . value)
+  (if (listp name)
+   `(fun ,(car name) ,(cdr name) ,@value)
+   `(setq ,name ,(car value))))
 (fun list x x)
 oh
 
